==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ChaikinVolatilityIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinVolatilityIndicatorDescription } from "./ChaikinVolatilityIndicatorDescription";
/**
 * @hidden
 */
var ChaikinVolatilityIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinVolatilityIndicatorDescriptionMetadata, _super);
    function ChaikinVolatilityIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinVolatilityIndicatorDescriptionMetadata.b = function (a) {
        if (ChaikinVolatilityIndicatorDescriptionMetadata.a == null) {
            ChaikinVolatilityIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChaikinVolatilityIndicatorDescriptionMetadata.c(ChaikinVolatilityIndicatorDescriptionMetadata.a);
        }
        if (a.g(ChaikinVolatilityIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(ChaikinVolatilityIndicatorDescriptionMetadata.a);
    };
    ChaikinVolatilityIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    ChaikinVolatilityIndicatorDescriptionMetadata.d = function (a) {
        ChaikinVolatilityIndicatorDescriptionMetadata.b(a);
        a.u("ChaikinVolatilityIndicator", function () { return new ChaikinVolatilityIndicatorDescription(); });
        a.t("ChaikinVolatilityIndicator", ChaikinVolatilityIndicatorDescriptionMetadata.a);
    };
    ChaikinVolatilityIndicatorDescriptionMetadata.$t = markType(ChaikinVolatilityIndicatorDescriptionMetadata, 'ChaikinVolatilityIndicatorDescriptionMetadata');
    ChaikinVolatilityIndicatorDescriptionMetadata.a = null;
    return ChaikinVolatilityIndicatorDescriptionMetadata;
}(Base));
export { ChaikinVolatilityIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ChaikinVolatilityIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinVolatilityIndicatorDescription } from "./ChaikinVolatilityIndicatorDescription";
/**
 * @hidden
 */
var ChaikinVolatilityIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ChaikinVolatilityIndicatorDescriptionMetadata, _super);
    function ChaikinVolatilityIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ChaikinVolatilityIndicatorDescriptionMetadata.b = function (a) {
        if (ChaikinVolatilityIndicatorDescriptionMetadata.a == null) {
            ChaikinVolatilityIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ChaikinVolatilityIndicatorDescriptionMetadata.c(ChaikinVolatilityIndicatorDescriptionMetadata.a);
        }
        if (a.j(ChaikinVolatilityIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(ChaikinVolatilityIndicatorDescriptionMetadata.a);
    };
    ChaikinVolatilityIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
    };
    ChaikinVolatilityIndicatorDescriptionMetadata.d = function (a) {
        ChaikinVolatilityIndicatorDescriptionMetadata.b(a);
        a.aa("ChaikinVolatilityIndicator", function () { return new ChaikinVolatilityIndicatorDescription(); });
        a.z("ChaikinVolatilityIndicator", ChaikinVolatilityIndicatorDescriptionMetadata.a);
    };
    ChaikinVolatilityIndicatorDescriptionMetadata.$t = markType(ChaikinVolatilityIndicatorDescriptionMetadata, 'ChaikinVolatilityIndicatorDescriptionMetadata');
    ChaikinVolatilityIndicatorDescriptionMetadata.a = null;
    return ChaikinVolatilityIndicatorDescriptionMetadata;
}(Base));
export { ChaikinVolatilityIndicatorDescriptionMetadata };
